sphinx_gallery.notebook — Python documentation

# sphinx_gallery.notebook

## Parser for Jupyter notebooks

Class that holds the Jupyter notebook information

### Functions

`sphinx_gallery.notebook.` `add_code_cell`(work_notebook, code)

  Add a code cell to the notebook

  Parameters

    code (str) – Cell content

`sphinx_gallery.notebook.` `add_markdown_cell`(work_notebook, text)

  Add a markdown cell to the notebook

  Parameters

    code (str) – Cell content

`sphinx_gallery.notebook.` `directive_fun`(match, directive)

  Helper to fill in directives

`sphinx_gallery.notebook.` `fill_notebook`(work_notebook, script_blocks)

  Writes the Jupyter notebook cells

  Parameters

    script_blocks (list) – Each list element should be a tuple of (label, content, lineno).

`sphinx_gallery.notebook.` `jupyter_notebook`(script_blocks, gallery_conf)

  Generate a Jupyter notebook file cell-by-cell

  Parameters

    - script_blocks (list) – Script execution cells.

    - gallery_conf (dict) – The sphinx-gallery configuration dictionary.

`sphinx_gallery.notebook.` `jupyter_notebook_skeleton`()

  Returns a dictionary with the elements of a Jupyter notebook

`sphinx_gallery.notebook.` `python_to_jupyter_cli`(args=None, namespace=None)

  Exposes the jupyter notebook renderer to the command line

  Takes the same arguments as ArgumentParser.parse_args

`sphinx_gallery.notebook.` `rst2md`(text)

  Converts the RST text from the examples docstrigs and comments into markdown text for the Jupyter notebooks

`sphinx_gallery.notebook.` `save_notebook`(work_notebook, write_file)

  Saves the Jupyter work_notebook to write_file